@@ -1,6 +1,6 @@
 #ifndef _SWAY_BUFFERS_H
 #define _SWAY_BUFFERS_H
-#include <cairo/cairo.h>
+#include <cairo.h>
 #include <stdbool.h>
 #include <stdint.h>
 #include <wayland-client.h>
@@ -9,14 +9,12 @@ struct pool_buffer {
 	struct wl_buffer *buffer;
 	cairo_surface_t *surface;
 	cairo_t *cairo;
-	uint32_t width, height;
 	void *data;
 	size_t size;
-	bool busy;
 };
 
-struct pool_buffer *get_next_buffer(struct wl_shm *shm,
-		struct pool_buffer pool[static 2], uint32_t width, uint32_t height);
+bool create_buffer(struct pool_buffer *buffer, struct wl_shm *shm,
+		int32_t width, int32_t height, uint32_t format);
 void destroy_buffer(struct pool_buffer *buffer);
 
 #endif
